/*
 * @Author: WangQiBiao
 * @Date: 2019-01-31 09:36:48
 * @Last Modified by: WangQiBiao
 * @Last Modified time: 2019-02-20 16:18:36
 */
import axios from '../../ libs/api.request'
export default {
  /**
   * 图片查看
   * @param id {string} 图片id
   */
  getFileImages (data) {
    return axios.request({
      url: `/file/images/${data.id}`,
      params: data,
      method: 'get'
    })
  },
  /**
   * 文件预览
   * @param {String} fileId 文件id
   * @param {Function} progressFunc 下载进度
   */
  previewCabinetFile (fileId, onDownloadProgress) {
    return this.downloadFileByConfig(
      `/serve/cabinetFile/preview/${fileId}`,
      {
        onDownloadProgress: onDownloadProgress,
        timeout: 1000 * 60 * 10 // 10分钟
      }
    )
  },
  previewCabinetFileByUrl (url, config) {
    return this.downloadFileByConfig(
      url,
      {
        ...config,
        responseType: 'blob'
      }
    )
  },
  /**
   * 文件下载
   * @param {String} fileId 文件id
   * @param {Function} progressFunc 下载进度
   */
  downloadFile (fileId, onDownloadProgress) {
    return this.downloadFileByConfig(
      `/file/download/${fileId}`,
      {
        onDownloadProgress: onDownloadProgress
      }
    )
  },
  /**
   * 文件下载
   * @param {String} url 文件下载地址
   * @param {Function} config 配置项
   */
  downloadFileByConfig (url, config, params = {}) {
    let defaultConfig = {
      url,
      method: 'get',
      params: params,
      responseType: 'blob',
      headers: {
        Accept: 'application/force-download;application/octet-stream;'
      }
    }
    return axios.request(Object.assign(defaultConfig, config))
  },
  postImageByManual (data) {
    return axios.request({
      url: '/file/images/upload',
      data: data,
      method: 'post',
      timeout: 1000 * 60 * 10 // 10分钟
    })
  }

}
